Skip to main contentModule execution
Source - commit_call
- Executes transaction and commits changes back to the underlying blockchain state.
- commit_call_with_async_and_callback
- Executes transaction and commits changes back to the underlying blockchain state.
- commit_deploy
- Executes deploy transaction and commits changes back to the underlying blockchain state.
- execute_deploy
- Runs transaction and produces a
TxResult. - execute_query
- Executes VM query and discards any changes to the blockchain state.